intelmq.bots.collectors.rt package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.collectors.rt package

## Submodules

## intelmq.bots.collectors.rt.collector_rt module

`intelmq.bots.collectors.rt.collector_rt.` `BOT`

  alias of `intelmq.bots.collectors.rt.collector_rt.RTCollectorBot`

class `intelmq.bots.collectors.rt.collector_rt.` `RTCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  `init`()
  `parameter_mapping` = {'search_owner': 'Owner', 'search_queue': 'Queue', 'search_requestor': 'Requestor', 'search_status': 'Status', 'search_subject_like': 'Subject__like'}
  `process`()

## Module contents